%define url_ver	%(echo %{version} | cut -d. -f1,2)

Summary:	Tag editor for MP3, OGG files
Name:		easytag
Version:	2.4.3
Release:	%mkrel 5
# Program is GPL only the included libapetag is LGPL
License:	GPLv2+ and LGPLv2+
Group:		Sound/Utilities
URL:		https://wiki.gnome.org/Apps/EasyTAG
Source0:	https://download.gnome.org/sources/easytag/%{url_ver}/%{name}-%{version}.tar.xz
Patch02:	02_fix-ogg-corruption.patch

# Needed for AppData.
BuildRequires:	libtool
BuildRequires:	yelp-tools
BuildRequires:	appdata-tools >= 0.1.7
# provide appdata-xml.m4
BuildRequires:	pkgconfig(appstream-glib)

BuildRequires:	intltool
BuildRequires:	itstool
BuildRequires:	pkgconfig(gtk+-2.0) >= 2.4
BuildRequires:	id3lib-devel
BuildRequires:	pkgconfig(id3tag)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	pkgconfig(flac)
BuildRequires:	pkgconfig(wavpack)
BuildRequires:	pkgconfig(speex)
BuildRequires:	pkgconfig(taglib)
BuildRequires:	pkgconfig(opusfile)
BuildRequires:	pkgconfig(libnautilus-extension)
BuildRequires:	docbook-dtds
BuildRequires:	docbook-style-xsl
BuildRequires:	xsltproc

%description
EasyTAG is an utility for viewing and editing tags of MP3, MP2, FLAC,
Ogg Vorbis, MP4/AAC, MusePack, Wavpack, Speex and Monkey's Audio
files. Its simple and nice GTK+ interface makes tagging easier under
GNU/Linux.
Features:
- View, edit, write tags of MP3, MP2 files (ID3 tag with pictures),
  FLAC files (FLAC Vorbis tag), Ogg Vorbis files (Ogg Vorbis tag),
  MP4/AAC (MP4/AAC tag), and MusePack, Wavpack, Monkey's Audio files
  (APE tag), Speex files,
- Auto tagging: parse filename and directory to complete automatically
  the fields (using masks),
- Ability to rename files and directories from the tag (using masks) or by
  loading a text file,
- Process selected files of the selected directory,
- Recursion for tagging, removing, renaming, saving...,
- Can set a field (artist, title,...) to all other files,
- Read file header informations (bitrate, time, ...) and display them,
- Ability to open a directory or a file with an external program,
- CDDB support (manual and automatic search),
- A tree based browser or a view by Artist & Album,
- A playlist generator window,

%package nautilus
Summary:	Nautilus extension for opening in EasyTAG
Group:		Sound/Utilities
License:	GPLv3+
Requires:	%{name} = %{version}-%{release}

%description nautilus
Nautilus extension to add "Open with EasyTAG" to the Nautilus context menu, for
easier access to EasyTAG when opening directories and audio files.

%prep
%setup -q
%autopatch -p1
NOCONFIGURE=1 ./autogen.sh

%build
%configure --disable-tests --disable-appdata-validate
%make_build

%install
%make_install
%find_lang %{name} --with-gnome

desktop-file-install \
	--vendor="" \
	--remove-mime-type="inode/directory" \
	--dir %{buildroot}%{_datadir}/applications \
		%{buildroot}%{_datadir}/applications/*

rm %buildroot%{_libdir}/nautilus/extensions-3.0/libnautilus-easytag.la

%check
make check

%files -f %{name}.lang
%doc ChangeLog README TODO THANKS HACKING
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.*
%{_datadir}/icons/hicolor/*/apps/%{name}-symbolic.*
%{_datadir}/metainfo/%{name}.appdata.xml
%{_datadir}/glib-2.0/schemas/*

%files nautilus
%{_libdir}/nautilus/extensions-3.0/libnautilus-easytag.so
%{_datadir}/metainfo/%{name}-nautilus.metainfo.xml


%changelog
* Thu Feb 13 2020 daviddavid <daviddavid> 2.4.3-5.mga8
+ Revision: 1513158
- disable appdata validation
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 2.4.3-4.mga7
+ Revision: 1297548
- Mageia 7 Mass Rebuild

* Wed Apr 18 2018 daviddavid <daviddavid> 2.4.3-3.mga7
+ Revision: 1219961
- add patch to revert upstream commit which causes OGG corruption (mga#22382)

* Tue Sep 12 2017 cjw <cjw> 2.4.3-2.mga7
+ Revision: 1153327
- fix filelist
- rebuild for new find_lang

* Mon Dec 05 2016 ovitters <ovitters> 2.4.3-1.mga6
+ Revision: 1072643
- new version 2.4.3

* Mon Feb 22 2016 daviddavid <daviddavid> 2.4.2-1.mga6
+ Revision: 976064
- new version: 2.4.2

* Tue Jan 26 2016 ovitters <ovitters> 2.4.1-1.mga6
+ Revision: 927666
- new version 2.4.1

* Tue Oct 27 2015 ycantin <ycantin> 2.4.0-2.mga6
+ Revision: 895802
- fix build : add a BR to get appdata-xml.m4

* Sat Aug 29 2015 ovitters <ovitters> 2.4.0-1.mga6
+ Revision: 870893
- new version 2.4.0

* Sat Jun 20 2015 ovitters <ovitters> 2.3.7-1.mga6
+ Revision: 836326
- new version 2.3.7
+ vaci0 <vaci0>
- Update to new version 2.3.6
+ gw666 <gw666>
- enable Opus support

* Fri Jan 02 2015 vaci0 <vaci0> 2.3.3-1.mga5
+ Revision: 808177
- Update to new version 2.3.3
- Disable tests during make check
+ gw666 <gw666>
- sync with fedora:
 * add nautilus extension
 * update license
 * add patches from upstream to update appdata
 * enable make check

* Wed Oct 15 2014 umeabot <umeabot> 2.2.4-2.mga5
+ Revision: 748915
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 wally <wally> 2.2.4-1.mga5
+ Revision: 732521
- new version 2.2.4

* Tue Sep 16 2014 umeabot <umeabot> 2.2.3-3.mga5
+ Revision: 678913
- Mageia 5 Mass Rebuild

* Mon Jun 23 2014 ovitters <ovitters> 2.2.3-2.mga5
+ Revision: 638813
- fix url

* Sun Jun 22 2014 ovitters <ovitters> 2.2.3-1.mga5
+ Revision: 638757
- new version 2.2.3

* Fri May 09 2014 ovitters <ovitters> 2.2.2-1.mga5
+ Revision: 621571
- new version 2.2.2

* Tue Apr 22 2014 ovitters <ovitters> 2.2.1-1.mga5
+ Revision: 617476
- new version 2.2.1

* Sat Apr 12 2014 ovitters <ovitters> 2.2.0-1.mga5
+ Revision: 613555
- new version 2.2.0

* Wed Feb 19 2014 ovitters <ovitters> 2.1.10-1.mga5
+ Revision: 594891
- new version 2.1.10

* Wed Feb 05 2014 dams <dams> 2.1.9-1.mga5
+ Revision: 582813
- update BR (docbook-dtds)
- new version 2.1.9
- remove useless patches and sources

* Sat Oct 19 2013 umeabot <umeabot> 2.1.8-3.mga4
+ Revision: 534773
- Mageia 4 Mass Rebuild

* Sat Sep 14 2013 gw666 <gw666> 2.1.8-2.mga4
+ Revision: 478788
- add patch to fix double scanning of a directory
- enable m4a support by using the right build dep on taglib

* Fri Apr 05 2013 wally <wally> 2.1.8-1.mga3
+ Revision: 408339
- new version 2.1.8 final
- add various fixes from upstream git
- remove directory mime-type from .desktop file
- clean .spec a bit

* Fri Jan 11 2013 umeabot <umeabot> 2.1.8-0.20120618.5.mga3
+ Revision: 349291
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ gw666 <gw666>
- bump libmp4v2 dep

* Sun Jan 06 2013 tv <tv> 2.1.8-0.20120618.4.mga3
+ Revision: 339871
- simplify description

* Sun Jan 06 2013 cjw <cjw> 2.1.8-0.20120618.3.mga3
+ Revision: 339867
- patch1: fix build with automake 1.13

* Thu Nov 29 2012 barjac <barjac> 2.1.8-0.20120618.2.mga3
+ Revision: 323120
- changed group in line with policy
- changed release to use mkrel -c

* Tue Jul 31 2012 vaci0 <vaci0> 2.1.8-0.20120618.1.mga3
+ Revision: 276480
- Updated version to 2.1.8 rev 20120618
- Clean spec file

* Sat Jun 16 2012 fwang <fwang> 2.1.7-2.mga3
+ Revision: 261001
- add upstream patch to build with latest mp4v2

* Sat Mar 03 2012 dams <dams> 2.1.7-1.mga2
+ Revision: 217599
- new version 2.1.7
- remove DE translation (now upstream)

* Sat Apr 02 2011 ahmad <ahmad> 2.1.6-11.mga1
+ Revision: 79813
- drop old unneeded scriptlets
- configure with --enable-shared and --disable-static
- imported package easytag


* Sun Dec 05 2010 Oden Eriksson <oeriksson@mandriva.com> 2.1.6-10mdv2011.0
+ Revision: 610332
- rebuild

* Fri Mar 12 2010 Götz Waschk <waschk@mandriva.org> 2.1.6-9mdv2010.1
+ Revision: 518308
- fix desktop entry

* Thu Aug 20 2009 Götz Waschk <waschk@mandriva.org> 2.1.6-8mdv2010.0
+ Revision: 418736
- fix cddb manual search (bug #53022)
- import for cooker

* Mon Jul 13 2009 Götz Waschk <waschk@mandriva.org> 2.1.6-7mdv2010.0
+ Revision: 395452
- replace mp4v2 patch by Gentoo version

* Thu May 28 2009 Götz Waschk <waschk@mandriva.org> 2.1.6-6mdv2010.0
+ Revision: 380340
- merge patches 0 and 1 to support both mp4v2 APIs

* Thu May 28 2009 Funda Wang <fwang@mandriva.org> 2.1.6-5mdv2010.0
+ Revision: 380322
- Build with newer mp4v2

* Mon Jan 12 2009 Götz Waschk <waschk@mandriva.org> 2.1.6-4mdv2009.1
+ Revision: 328563
- build with new libmp4v2

* Sun Sep 21 2008 Götz Waschk <waschk@mandriva.org> 2.1.6-3mdv2009.0
+ Revision: 286326
- revert previous change, readd directory mime type

* Thu Sep 18 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 2.1.6-2mdv2009.0
+ Revision: 285580
- remove x-directory/normal mimetype, as it leads to open easytag instead of default file browser ins some circumstances
- new license policy
- remove redefines
- do not package COPYING and INSTALL files
- spec file clean

* Mon Jul 14 2008 Götz Waschk <waschk@mandriva.org> 2.1.6-1mdv2009.0
+ Revision: 235604
- new version
- update German translation

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

* Wed Apr 09 2008 Götz Waschk <waschk@mandriva.org> 2.1.5-2mdv2009.0
+ Revision: 192438
- build with mp4 metadata support

* Sun Jan 27 2008 Götz Waschk <waschk@mandriva.org> 2.1.5-1mdv2008.1
+ Revision: 158854
- new version
- drop patch
- update German translation

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Dec 10 2007 Götz Waschk <waschk@mandriva.org> 2.1.4-2mdv2008.1
+ Revision: 116940
- fix build

* Mon Dec 10 2007 Götz Waschk <waschk@mandriva.org> 2.1.4-1mdv2008.1
+ Revision: 116921
- new version
- drop patches
- update German translation

* Tue Oct 16 2007 Götz Waschk <waschk@mandriva.org> 2.1.3-4mdv2008.1
+ Revision: 99026
- bump release
- release bump
- fix desktop entry again
- fix buildrequires

* Tue Oct 16 2007 Götz Waschk <waschk@mandriva.org> 2.1.3-1mdv2008.1
+ Revision: 98867
- fix build with new mpeg4ip
- new version
- update German translation
- fix desktop entry
- drop legacy menu

* Thu Jul 12 2007 Götz Waschk <waschk@mandriva.org> 2.1.2-1mdv2008.0
+ Revision: 51467
- new version
- update German translation

* Thu Jul 05 2007 Götz Waschk <waschk@mandriva.org> 2.1.1-1mdv2008.0
+ Revision: 48448
- new version
- drop all patches (merged)
- update German translation
- update buildrequires
- update description

* Tue Jun 19 2007 Götz Waschk <waschk@mandriva.org> 2.1-4mdv2008.0
+ Revision: 41418
- fix file rename bug

* Fri Jun 15 2007 Götz Waschk <waschk@mandriva.org> 2.1-3mdv2008.0
+ Revision: 39876
- fix FLAC comments

* Sat May 26 2007 Götz Waschk <waschk@mandriva.org> 2.1-2mdv2008.0
+ Revision: 31364
- patch for libid3tag support

* Tue May 08 2007 Götz Waschk <waschk@mandriva.org> 2.1-1mdv2008.0
+ Revision: 24993
- new version
- update German translation

* Wed May 02 2007 Götz Waschk <waschk@mandriva.org> 2.0.2-1mdv2008.0
+ Revision: 20392
- new version
- drop merged de.po

* Fri Apr 20 2007 Götz Waschk <waschk@mandriva.org> 2.0.1-1mdv2008.0
+ Revision: 15406
- new version
- update German translation
- drop patch
- update description
- update buildrequires

* Tue Apr 17 2007 Götz Waschk <waschk@mandriva.org> 2.0-2mdv2007.1
+ Revision: 13639
- remove glib warning


* Fri Feb 23 2007 Götz Waschk <waschk@mandriva.org> 2.0-1mdv2007.0
+ Revision: 124855
- new version
- drop source 1
- fix doc file listing

* Tue Dec 12 2006 Götz Waschk <waschk@mandriva.org> 1.99.13-1mdv2007.1
+ Revision: 95213
- new version
- update German translation
- drop patches
- switch back to id3lib

* Mon Dec 11 2006 Götz Waschk <waschk@mandriva.org> 1.99.12-5mdv2007.1
+ Revision: 95023
- bump release

* Mon Dec 11 2006 Götz Waschk <waschk@mandriva.org> 1.99.12-4mdv2007.1
+ Revision: 94989
- Import easytag

* Mon Dec 11 2006 Götz Waschk <waschk@mandriva.org> 1.99.12-4mdv2007.1
- patch for new libflac
- libid3tag patch

* Tue Jun 20 2006 Götz Waschk <waschk@mandriva.org> 1.99.12-3mdv2007.0
- use the new macro
- fix xdg menu

* Mon May 22 2006 Götz Waschk <waschk@mandriva.org> 1.99.12-2mdk
- use the XDG menu
- own the data dir

* Tue Apr 11 2006 Götz Waschk <waschk@mandriva.org> 1.99.12-1mdk
- update German translation
- New release 1.99.12

* Fri Dec 16 2005 Götz Waschk <waschk@mandriva.org> 1.99.11-1mdk
- update German translation
- New release 1.99.11

* Tue Nov 29 2005 Götz Waschk <waschk@mandriva.org> 1.99.10-1mdk
- update German translation
- update docs list
- new version

* Thu Nov 03 2005 Götz Waschk <waschk@mandriva.org> 1.99.9-1mdk
- update German translation
- New release 1.99.9

* Tue Sep 06 2005 Götz Waschk <waschk@mandriva.org> 1.99.8-3mdk
- update description

* Tue Sep 06 2005 Götz Waschk <waschk@mandriva.org> 1.99.8-2mdk
- fix buildrequires

* Fri Sep 02 2005 Götz Waschk <waschk@mandriva.org> 1.99.8-1mdk
- conditional faac support
- update de.po
- New release 1.99.8

* Tue Aug 16 2005 Götz Waschk <waschk@mandriva.org> 1.99.7-2mdk
- update de.po

* Wed Jul 13 2005 Götz Waschk <waschk@mandriva.org> 1.99.7-1mdk
- drop source1
- drop patch
- New release 1.99.7

* Thu Jun 30 2005 Götz Waschk <waschk@mandriva.org> 1.99.6-2mdk
- fix for a browser entry bug

* Mon Jun 27 2005 Götz Waschk <waschk@mandriva.org> 1.99.6-1mdk
- update source 1
- drop patch
- New release 1.99.6

* Thu Jun 16 2005 Götz Waschk <waschk@mandriva.org> 1.99.5-4mdk
- German translation update

* Tue Jun 14 2005 Götz Waschk <waschk@mandriva.org> 1.99.5-3mdk
- mkrel

* Sat Jun 11 2005 Götz Waschk <waschk@mandriva.org> 1.99.5-2mdk
- patch: add disc number support to the tag scanner

* Wed Jun 08 2005 Götz Waschk <waschk@mandriva.org> 1.99.5-1mdk
- update the german translation
- New release 1.99.5

* Tue May 03 2005 Götz Waschk <waschk@mandriva.org> 1.99.4-1mdk
- update the german translation
- drop the patch
- New release 1.99.4

* Tue Apr 19 2005 Götz Waschk <waschk@linux-mandrake.com> 1.99.3-2mdk
- rebuild for new libflac

* Fri Jan 21 2005 Götz Waschk <waschk@linux-mandrake.com> 1.99.3-1mdk
- update german translation
- New release 1.99.3

* Tue Nov 30 2004 Götz Waschk <waschk@linux-mandrake.com> 1.99.2-1mdk
- update german translation
- update source URL
- New release 1.99.2

* Wed Oct 27 2004 Götz Waschk <waschk@linux-mandrake.com> 1.99.1-1mdk
- update German translation
- new version

* Fri Oct 01 2004 Götz Waschk <waschk@linux-mandrake.com> 0.31-8mdk
- small build patch
- update german translation
- drop patches
- new prerelease

* Thu Sep 30 2004 Götz Waschk <waschk@linux-mandrake.com> 0.31-7mdk
- fix cddb bug

* Mon Sep 13 2004 Götz Waschk <waschk@linux-mandrake.com> 0.31-6mdk
- update german translation
- patch in cover viewer
- new prerelease

* Tue Aug 03 2004 Götz Waschk <waschk@linux-mandrake.com> 0.31-5mdk
- rebuild for new flac

* Sat Jul 17 2004 Götz Waschk <waschk@linux-mandrake.com> 0.31-4mdk
- update german translation
- new prerelease

* Mon Jul 05 2004 Götz Waschk <waschk@linux-mandrake.com> 0.31-3mdk
- use imagemagick for the icons
- update german translation
- gtk2 prerelease

* Sat Jun 05 2004 Götz Waschk <waschk@linux-mandrake.com> 0.31-2mdk
- rebuild for new g++

* Tue Jun 01 2004 Götz Waschk <waschk@linux-mandrake.com> 0.31-1mdk
- update german translation
- new version

* Sat Apr 03 2004 Götz Waschk <waschk@linux-mandrake.com> 0.30.2-1mdk
- new version

* Tue Mar 23 2004 Götz Waschk <waschk@linux-mandrake.com> 0.30.1-1mdk
- update file list
- drop all patches
- new version

